@@ -2,7 +2,7 @@
 # This code is part of the MAterials Simulation Toolkit (MAST)
 # 
 # Maintainer: Tam Mayeshiba
-# Last updated: 2014-05-12 by Zhewen Song
+# Last updated: 2014-06-13 by Zhewen Song
 ##############################################################
 import os, re
 import logging
@@ -17,7 +17,7 @@ from MAST.recipe import recipeutility as ru
 from MAST.recipe.recipeplan import RecipePlan
 from MAST.ingredients.baseingredient import BaseIngredient
 ALLOWED_KEYS = {
-                  'recipeFile'     : (str, None, 'Personalized recipe file'),\
+                  'recipeFile'     : (list, None, 'Personalized recipe file'),\
                   'inputOptions'   : (InputOptions, None, 'Input options parsed using input parser'),\
                   'structure'      : (Structure, None, 'Structure to be used to create the ingredient objects'),\
                   'ingredientsDict': (dict, dict(), 'Dictionary of ingredients'),\
@@ -50,7 +50,7 @@ class RecipeSetup(MASTObj):
         self.recipe_logger = loggerutils.add_handler_for_recipe(self.work_dir, self.recipe_logger)
 
         self.metafile = Metadata(metafile='%s/metadata.txt' % self.work_dir)
-        self.recipe_logger.info('Setting up the recipe based on %s' % (self.recipe_file))
+        self.recipe_logger.info('Setting up the recipe based on the personal recipe contents passed in self.recipe_file')
 
     def get_my_ingredient_options(self, name, ingredient_type):
         """Creates the ingredient based on the ingredient type.
@@ -189,9 +189,9 @@ class RecipeSetup(MASTObj):
         """
         import inspect
         #'GRJ DEBUG: %s.%s' % (self.__class__.__name__, inspect.stack()[0][3])
-        [how_to_update, parents_to_check, how_to_run, recipe_name] = ru.read_recipe(self.recipe_file)
+        [how_to_update, parents_to_check, how_to_run] = ru.read_recipe(self.recipe_file)
 
-        recipe_obj = RecipePlan(recipe_name, self.work_dir)
+        recipe_obj = RecipePlan(self.work_dir)
         ingredlist = how_to_run.keys()
         for ingred in ingredlist:
             self.update_top_meta_for_ingred(ingred)
@@ -219,13 +219,15 @@ class RecipeSetup(MASTObj):
         """
         datalist=list()
         datalist.append("ingredient type: %s " % myingred)
-        scaling = re.search(r'_\d*x\d*x\d*',myingred)
+        scaling = self.input_options.get_item('structure','scaling')
+        scalingsize = None
         if scaling: 
-            scalingsize=scaling.group().split('_')[1]
-            datalist.append("scaling_size: %s" % scalingsize)
-            d_scaling = self.input_options.get_item("structure","scaling")
-            kpoints = d_scaling[scalingsize]
-            datalist.append("kpoints: %s %s %s" % (kpoints[0],kpoints[1],kpoints[2]) )
+            for sckeys in scaling.keys():
+                if sckeys in myingred:
+                    scalingsize = sckeys
+            if scalingsize:
+                datalist.append("scaling_size: [%s]" % scaling[scalingsize][0])
+                datalist.append("kpoints: %s %s %s" % (scaling[scalingsize][-3],scaling[scalingsize][-2],scaling[scalingsize][-1]))
         if 'defect_' in myingred:
             if scaling:
                 defectlabel = myingred.split('defect_')[1].split('_')[1]
@@ -257,7 +259,7 @@ class RecipeSetup(MASTObj):
             phononlabel = '_'.join(labels)
             datalist.append("phonon_label: %s" % phononlabel)
         data=';'.join(datalist)
-        self.metafile.write_data(myingred, data)
+        self.metafile.write_data(myingred, data, 1)
 
     def create_ingredient(self, my_ingred_input_options):
         """Create the ingredient directory and metadata file.
@@ -286,11 +288,11 @@ class RecipeSetup(MASTObj):
            Use the input options and recipe info to
            create directories and classes required
         """
-        if self.recipe_file is None:
-            raise MASTError(self.__class__.__name__, "Recipe file not provided!")
+        if not self.recipe_file:
+            raise MASTError(self.__class__.__name__, "Recipe contents are empty!")
 
-        if not os.path.exists(self.recipe_file):
-            raise MASTError(self.__class__.__name__, "Recipe file not Found!")
+        """if not os.path.exists(self.recipe_file):
+            raise MASTError(self.__class__.__name__, "Recipe file not Found!")"""
 
         if not self.input_options:
             raise MASTError(self.__class__.__name__, "Input Options not provided!")
