@@ -11,11 +11,11 @@ from MAST.utility import MASTFile
 from MAST.utility import MASTError
 
 """Utility to read the indented recipe file."""
-def read_recipe(filename, verbose=0):
+def read_recipe(rawrlist, verbose=0):
     """Read the indented recipe.
         "Recipe" is a protected keyword signaling the recipe name.
         Args:
-            filename <str>: Full path to recipe file
+            rawrlist <list of str>: List of recipe lines from $recipe section of input file
         Returns:
             totpdict <dict>: Dictionary of 
                 [parentname][child]=[parent method group]
@@ -27,17 +27,20 @@ def read_recipe(filename, verbose=0):
     logger=logging.getLogger('mast')
     logger=loggerutils.add_handler_for_control(logger)
 
-    rfile = MASTFile(filename)
+    rfile = list(rawrlist) #MASTFile(filename)
     rdata = list()
     #preprocess by removing blank lines and any "recipe" line
-    for line in rfile.data:
+    for line in rfile:
+        duplicate = line
+        if ((len(duplicate) - len(duplicate.lstrip(' '))) % 4 != 0):
+            raise MASTError("recipe/recipeutility", "Recipe at %s contains incorrect number of whitespace chars at the beginning of the line! Please convert all indentations to the appropriate number of groups of four spaces." % filename)
         if '\t' in line:
             raise MASTError("recipe/recipeutility", "Recipe at %s contains tabs! Please convert all indentations to the appropriate number of groups of four spaces." % filename)
         myline = line.rstrip() #right-hand strip of carriage return only
         if len(myline) == 0: #blank line
             pass
-        elif (len(myline) > 6) and (myline[0:6].lower() == "recipe"):
-            rname = myline.split()[1]
+        #elif (len(myline) > 6) and (myline[0:6].lower() == "recipe"):
+            #rname = myline.split()[1]	  
         elif myline.strip()[0] == "#": #comment line, hash starting wherever
             pass
         else:
@@ -81,7 +84,7 @@ def read_recipe(filename, verbose=0):
         for ckey in clist:
             logger.info("%s: %s" % (ckey, howtorun[ckey]))
 
-    return [howtoupdate, parentstocheck, howtorun, rname]
+    return [howtoupdate, parentstocheck, howtorun]
 
 def split_into_subrecipes(mydata):
     """Split an entire recipe into subrecipes. Each new zero-level 
@@ -230,3 +233,4 @@ def make_indentation_dictionary(subrlist):
         for parent in pdict.keys():
             idict[indent].append([lct, parent, pdict[parent]])
     return idict
+
