@@ -31,14 +31,27 @@ def get_citations(recipedir):
                 for mastxc in mastxcs:
                     if ("pw" in mastxc.lower()) or ("paw" in mastxc.lower()):
                         mylist.append('vasp_paw')
+            mastprogs = fileutil.grepme(myinput, "mast_program")
+            if len(mastprogs) >= 1:
+                for mastprog in mastprogs:
+                    if ("vasp_neb" in mastprog.lower()):
+                        mylist.append('vaspneb')
+            if "tst" in mastexec.lower():
+                mylist.append('vaspneb')
         #if 'phon' in mastexec.lower():
         #    mylist.append('phon')
         if 'structopt' in mastexec.lower():
             mylist.append('structopt')
-    citationpath = os.path.join(dirutil.get_mast_control_path(),"citations")
+    citationpath = os.path.join(dirutil.get_mast_install_path(),
+                    "summary","citations")
     citationfiles = os.listdir(citationpath)
     linelist = list()
-    for listitem in mylist:
+    uniquelist=list()
+    for mylistitem in mylist:
+        if not mylistitem in uniquelist:
+            uniquelist.append(mylistitem)
+    #print "UNIQUELIST: ", uniquelist
+    for listitem in uniquelist:
         for citationfile in citationfiles:
             if citationfile[:-3] == listitem: #all except number
                 cfpath = os.path.join(citationpath, citationfile)
