@@ -130,11 +130,8 @@ def walkfiles(existdir, mindepth=1, maxdepth=5, matchme=""):
         return paredfilelist
 
 def get_mast_install_path():
-    raise NotImplementedError("MAST_INSTALL_PATH environment variable is no longer being used.")
-    getpath = os.getenv('MAST_INSTALL_PATH')
-    if getpath == None:
-        raise MASTError("utility dirutil","No path set in environment variable MAST_INSTALL_PATH")
-    return getpath
+    import MAST
+    return os.path.dirname(MAST.__file__)
 def get_mast_scratch_path():
     getpath = os.getenv('MAST_SCRATCH')
     if getpath == None:
@@ -152,6 +149,12 @@ def get_mast_control_path():
     if getpath == None:
         raise MASTError("utility dirutil","No path set in environment variable MAST_CONTROL")
     return getpath
+def get_mast_recipe_path():
+    raise NotImplementedError("MAST_RECIPE_PATH is an obsolete environment variable and should no longer be used.")
+    getpath = os.getenv('MAST_RECIPE_PATH')
+    if getpath == None:
+        raise MASTError("utility dirutil","No path set in environment variable MAST_RECIPE_PATH")
+    return getpath
 def directory_is_locked(dirname):
     if os.path.isfile(dirname + "/mast.write_files.lock"):
         return True
@@ -306,3 +309,10 @@ def get_test_dir(testname):
         testdir = os.path.join(testdir, "test")
     testdir = os.path.join(testdir, testname)
     return testdir
+
+def get_version():
+    """Get MAST version from MAST/_version.py file"""
+    vfile = open(os.path.join(get_mast_install_path(),"_version.py"),"rb")
+    vline = vfile.readline()
+    vnum = vline.split("=")[1].strip().strip('"')
+    return vnum
